@@ -9,6 +9,8 @@
 #include <orc/orcdebug.h>
 #include <orc/orconce.h>
 
+#include "orcinternal.h"
+
 /**
  * SECTION:orc
  * @title: Orc
@@ -58,6 +60,9 @@ orc_init (void)
 #ifdef ENABLE_BACKEND_NEON
       orc_neon_init();
 #endif
+#ifdef ENABLE_BACKEND_MIPS
+      orc_mips_init();
+#endif
 
       inited = TRUE;
     }
