@@ -162,11 +162,23 @@ orc_program_free (OrcProgram *program)
       free (program->vars[i].name);
       program->vars[i].name = NULL;
     }
+    if (program->vars[i].type_name) {
+      free (program->vars[i].type_name);
+      program->vars[i].type_name = NULL;
+    }
   }
   if (program->asm_code) {
     free (program->asm_code);
     program->asm_code = NULL;
   }
+  if (program->orccode) {
+    orc_code_free (program->orccode);
+    program->orccode = NULL;
+  }
+  if (program->init_function) {
+    free (program->init_function);
+    program->init_function = NULL;
+  }
   if (program->name) {
     free (program->name);
     program->name = NULL;
@@ -814,6 +826,7 @@ orc_program_append_str (OrcProgram *program, const char *name,
   insn->opcode = orc_opcode_find_by_name (name);
   if (!insn->opcode) {
     ORC_ERROR ("unknown opcode: %s", name);
+    return;
   }
   insn->dest_args[0] = orc_program_find_var_by_name (program, arg1);
   if (insn->opcode->dest_size[1] != 0) {
