@@ -11,13 +11,12 @@
 #include <orc-test/orcprofile.h>
 
 
-#define ALIGN(ptr,n) ((void *)((orc_intptr)(ptr) & (~(orc_intptr)(n-1))))
+#define ALIGN(ptr,n) ((void *)((orc_intptr)(ptr + n) & (~(orc_intptr)(n-1))))
 
 int hot_src = TRUE;
 int hot_dest = TRUE;
 int flush_cache = FALSE;
 
-
 void
 touch (unsigned char *ptr, int n)
 {
@@ -44,11 +43,11 @@ main(int argc, char *argv[])
   OrcProgram *p;
   int level1, level2, level3;
   int max;
-  //const uint8_t zero = 0;
+  /* const uint8_t zero = 0; */
 
   orc_init ();
 
-  //cpufreq = 2333e6;
+  /* cpufreq = 2333e6; */
   cpufreq = 1;
 
   if (argc > 1) {
@@ -74,10 +73,10 @@ main(int argc, char *argv[])
 
     p = orc_program_new ();
     orc_program_set_name (p, "orc_memcpy");
-    //orc_program_set_name (p, "orc_memset");
+    /* orc_program_set_name (p, "orc_memset"); */
     orc_program_add_destination (p, 1, "d1");
     orc_program_add_source (p, 1, "s1");
-    //orc_program_add_parameter (p, 1, "p1");
+    /* orc_program_add_parameter (p, 1, "p1"); */
 
     orc_program_append (p, "copyb", ORC_VAR_D1, ORC_VAR_S1, ORC_VAR_D1);
 
@@ -121,7 +120,7 @@ main(int argc, char *argv[])
       void (*func) (OrcExecutor *);
 
       orc_profile_start(&prof);
-      //orc_memcpy (dest, src, size);
+      /* orc_memcpy (dest, src, size); */
       ex->program = p;
       ex->n = size;
       ex->arrays[ORC_VAR_D1] = dest;
@@ -164,16 +163,20 @@ main(int argc, char *argv[])
     ave -= null;
     ave_libc -= null;
 
-    //printf("%d: %10.4g %10.4g %10.4g %10.4g (libc %10.4g)\n", i, ave, std,
-    //    ave/(1<<i), cpufreq/(ave/(1<<i)),
-    //    cpufreq/(ave_libc/(1<<i)));
+    /* printf("%d: %10.4g %10.4g %10.4g %10.4g (libc %10.4g)\n", i, ave, std, */
+    /*     ave/(1<<i), cpufreq/(ave/(1<<i)), */
+    /*     cpufreq/(ave_libc/(1<<i))); */
     printf("%g %10.4g %10.4g\n", x,
         cpufreq/(ave/size), cpufreq/(ave_libc/size));
-    //printf("%g %10.4g %10.4g\n", x,
-    //    32*(ave/(size)), 32*(ave_libc/(size)));
+    /* printf("%g %10.4g %10.4g\n", x, */
+    /*     32*(ave/(size)), 32*(ave_libc/(size))); */
     fflush (stdout);
   }
 
+  orc_program_free (p);
+  free (s);
+  free (d);
+
   return 0;
 }
 
