@@ -41,11 +41,14 @@ main (int argc, char *argv[])
   }
 
   n = orc_parse (code, &programs);
+  free (code);
 
   for(i=0;i<n;i++){
     printf("%-30s %g\n", programs[i]->name,
         orc_test_performance_full (programs[i], 0, NULL));
+    orc_program_free (programs[i]);
   }
+  free (programs);
 
   if (error) return 1;
   return 0;
